cda.codeset = {}

local function Reverse(T)
   local Y = {}
   for K,V in pairs(T) do
      Y[V] = K
   end
   return Y
end

-- A list of OIDs for codesets in this module (plus some other common codesets)
cda.codeset.cat = {
   ["HL7 Observation Interpretation"]              = "2.16.840.1.113883.1.11.78",
   ["Personal Relationship Role"]                  = "2.16.840.1.113883.1.11.19563",   
   ["NCI - FDA RouteOfAdministration"]             = "2.16.840.1.113883.3.26.1.1",
   SSN                                             = "2.16.840.1.113883.4.1",
   ["National Provider Identifier"]                = "2.16.840.1.113883.4.6",
   ["HL7 AdministrativeGender"]                    = "2.16.840.1.113883.5.1",
   ["HL7 Marital status"]                          = "2.16.840.1.113883.5.2",
   ["HL7 ActCode"]                                 = "2.16.840.1.113883.5.4",
   ["HL7 Act Class"]                               = "2.16.840.1.113883.5.6",
   ["HL7 Act Priority"]                            = "2.16.840.1.113883.5.7",
   ["HL7 ActStatus"]                               = "2.16.840.1.113883.5.14",
   ["HL7 Act No Immunization Reason"]              = "2.16.840.1.113883.5.8",      
   ["HL7 Advance Directive Type"]                  = "2.16.840.1.113883.1.11.20.2",      
   Language                                        = "2.16.840.1.113883.1.11.11526",      
   ["HL7 Confidentiality"]                         = "2.16.840.1.113883.5.25",      
   ["HL7 EntityNameUse"]                           = "2.16.840.1.113883.5.45",      
   ["HL7 AdministrativeSex"]                       = "2.16.840.1.113883.12.1",      
   ["HL7 AddressUse"]                              = "2.16.840.1.113883.5.1119",      
   ["HL7 ParticipationSignature"]                  = "2.16.840.1.113883.5.89",      
   LanguageAbilityMode                             = "2.16.840.1.113883.5.60",  
   LanguageAbilityProficiency                      = "2.16.840.1.113883.5.61",
   ObservationInterpretation                       = "2.16.840.1.113883.5.83",
   ["HL7 Role Class Relationship"]                 = "2.16.840.1.113883.5.110",   
   ["HL7 Role Class"]                              = "2.16.840.1.113883.5.111",   
   ["HL7 RouteOfAdministration"]                   = "2.16.840.1.113883.5.112",
   ["ReligiousAffiliation"]                        = "2.16.840.1.113883.5.1076",
   ["HL7 Service Delivery Location"]               = "2.16.840.1.113883.5.10588",   
   LOINC                                           = "2.16.840.1.113883.6.1",
   ICD9CM                                          = "2.16.840.1.113883.6.2",
   UCUM                                            = "2.16.840.1.113883.6.8",
   CPT                                             = "2.16.840.1.113883.6.12",   
   RxNorm                                          = "2.16.840.1.113883.6.88",
   SNOMED_CT                                       = "2.16.840.1.113883.6.96",
   SNOMED                                          = "2.16.840.1.113883.6.96",
   ["Provider Codes"]                              = "2.16.840.1.113883.6.101",
   ["ICD-9CM (diagnoses)"]                         = "2.16.840.1.113883.6.103",
   ["ICD-9CM (procedure codes)"]                   = "2.16.840.1.113883.6.104",
   ["HL7 Race and Ethnicity"]                      = "2.16.840.1.113883.6.238",
   ["Healthcare Service Location"]                 = "2.16.840.1.113883.6.259",
   ICF                                             = "2.16.840.1.113883.6.254",   
   CVX                                             = "2.16.840.1.113883.12.292",
   ["HL7 Provider Role"]                           = "2.16.840.1.113883.12.443"
}

-- HL7 Template ID - Common template identifiers used to specify constraints for Sections and Entries (as specifed in CDA R2)
cda.codeset.templates = {
   ["Advanced Directives"] = "2.16.840.1.113883.10.20.22.2.21",
   ["Advanced Directives With Entries"] = "2.16.840.1.113883.10.20.22.2.21.1",
   ["Advanced Directives Observation"] = "2.16.840.1.113883.10.20.22.4.48",
   ["Advanced Directives Verification"] = "2.16.840.1.113883.10.20.1.58",
   ["Assessment"] = "2.16.840.1.113883.10.20.22.2.8",
   ["Interventions"] = "2.16.840.1.113883.10.20.21.2.3",
   ["Allergies, Adverse Reactions, Alerts"] = "2.16.840.1.113883.10.20.22.2.6",
   ["Allergies, Adverse Reactions, Alerts With Entries"] = "2.16.840.1.113883.10.20.22.2.6.1",
   ["Allergy Problem Act"] = "2.16.840.1.113883.10.20.22.4.30",
   ["Allergy Observation"] = "2.16.840.1.113883.10.20.22.4.7",
   ["Allergy Status Observation"] = "2.16.840.1.113883.10.20.22.4.28",
   ["Reaction Observation"] = "2.16.840.1.113883.10.20.22.4.9",
   ["Severity Observation"] = "2.16.840.1.113883.10.20.22.4.8",
   ["Encounters"] = '2.16.840.1.113883.10.20.22.2.22',
   ['Encounters With Entries'] = '2.16.840.1.113883.10.20.22.2.22.1',
   ["Encounter Activities"] = "2.16.840.1.113883.10.20.22.4.49",
   ["Service Delivery Location"] = "2.16.840.1.113883.10.20.22.4.32",
   ["Indication"] = "2.16.840.1.113883.10.20.22.4.19",
   ["Family History"] = "2.16.840.1.113883.10.20.22.2.15",
   ["Family History Organizer"] = "2.16.840.1.113883.10.20.22.4.45",
   ["Family History Observation"] = "2.16.840.1.113883.10.20.22.4.46",
   ["Family History Death Observation"] = "2.16.840.1.113883.10.20.22.4.47",
   ["Age Observation"] = "2.16.840.1.113883.10.20.22.4.31",
   ["Functional Status"] = "2.16.840.1.113883.10.20.22.2.14",
   ["Result Organizer"] = "2.16.840.1.113883.10.20.22.4.1",
   ["Function Status Result Organizer"] = "2.16.840.1.113883.10.20.22.4.66",
   ["Cognitive Status Result Organizer"] = "2.16.840.1.113883.10.20.22.4.75",
   ["Result Observation"] = "2.16.840.1.113883.10.20.22.4.2",
   ["Functional Status Result Observation"] = "2.16.840.1.113883.10.20.22.4.67",
   ["Cognitive Status Result Observation"] = "2.16.840.1.113883.10.20.22.4.74",   
   ["Assessment Scale Observation"] = "2.16.840.1.113883.10.20.22.4.69",
   ["Assessment Scale Supporting Observation"] = "2.16.840.1.113883.10.20.22.4.86",
   ["Caregiver Characteristics"] = "2.16.840.1.113883.10.20.22.4.72",
   ["Problem Observation"] = "2.16.840.1.113883.10.20.22.4.4",
   ["Functional Status Problem Observation"] = "2.16.840.1.113883.10.20.22.4.68",
   ["Cognitive Status Problem Observation"] = "2.16.840.1.113883.10.20.22.4.73",
   ["Immunizations"] = "2.16.840.1.113883.10.20.22.2.2",
   ["Immunizations With Entries"] = "2.16.840.1.113883.10.20.22.2.1",
   ["Immunization Activity"] = "2.16.840.1.113883.10.20.22.4.52",
   ["Immunization Medication Information"] = "2.16.840.1.113883.10.20.22.4.54",
   ["Instructions"] = "2.16.840.1.113883.10.20.22.4.20",
   ["Immunization Refusal"] = "2.16.840.1.113883.10.20.22.4.53",
   ["Medical Equipment"] = "2.16.840.1.113883.10.20.22.2.23",
   ["Non-medicinal Supply Activity"] = "2.16.840.1.113883.10.20.22.4.50",
   ["Product Instance"] = "2.16.840.1.113883.10.20.22.4.37",
   ["Plan of Care"] = "2.16.840.1.113883.10.20.22.2.10",
   ["Plan of Care Activity Observation"] = "2.16.840.1.113883.10.20.22.4.44",
   ["Plan of Care Act"] = "2.16.840.1.113883.10.20.22.4.39",
   ["Plan of Care Activity Encounter"] = "2.16.840.1.113883.10.20.22.4.40",
   ["Plan of Care Activity Procedure"] = "2.16.840.1.113883.10.20.22.4.41",
   ["Social History"] = "2.16.840.1.113883.10.20.22.2.17",
   ["Social History Observation"] = "2.16.840.1.113883.10.20.22.4.38",
   ["Smoking Status Observation"] = "2.16.840.1.113883.10.20.22.4.78",
   ["Medications"] = "2.16.840.1.113883.10.20.22.2.1",
   ["Medications With Entries"] = "2.16.840.1.113883.10.20.22.2.1.1",
   ["Medication Activity"] = "2.16.840.1.113883.10.20.22.4.16",
   ["Medication Information"] = "2.16.840.1.113883.10.20.22.4.23",
   ["Medication Drug Vehicle"] = "2.16.840.1.113883.10.20.22.4.24",
   ["Medication Indication"] = "2.16.840.1.113883.10.20.22.4.19",
   ["Medication Supply Order"] = "2.16.840.1.113883.10.20.22.4.17",
   ["Medication Instructions"] = "2.16.840.1.113883.10.20.22.4.20",
   ["Medication Dispense"] = "2.16.840.1.113883.10.20.22.4.18",
   ["Precondition for Substance Administration"] = "2.16.840.1.113883.10.20.22.4.25",
   ["Payers"] = "2.16.840.1.113883.10.20.22.2.18",
   ["Coverage Activity"] = "2.16.840.1.113883.10.20.22.4.60",
   ["Policy Activity"] = "2.16.840.1.113883.10.20.22.4.61",
   ["Payer Performer"] = "2.16.840.1.113883.10.20.22.4.87",
   ["Guarantor Performer"] = "2.16.840.1.113883.10.20.22.4.88",
   ["Covered Party Participant"] = "2.16.840.1.113883.10.20.22.4.89",
   ["Policy Holder"] = "2.16.840.1.113883.10.20.22.4.90",
   ["Authorization Activity"] = "2.16.840.1.113883.10.20.1.19",
   ["Procedures"] = "2.16.840.1.113883.10.20.22.2.7",
   ["Procedures With Entries"] = "2.16.840.1.113883.10.20.22.2.7.1",
   ["Procedure Activity Procedure"] = "2.16.840.1.113883.10.20.22.4.14",
   ["Procedure Activity Observation"] = "2.16.840.1.113883.10.20.22.4.13",
   ["Procedure Activity Act"] = "2.16.840.1.113883.10.20.22.4.12",  
   ["Product Instance"] = "2.16.840.1.113883.10.20.22.4.37",
   ["Service Delivery Location"] = "2.16.840.1.113883.10.20.22.4.32",
   ["Results"] = "2.16.840.1.113883.10.20.22.2.3",
   ["Results With Entries"] = "2.16.840.1.113883.10.20.22.2.3.1",
   ["Vital Signs"] = "2.16.840.1.113883.10.20.22.2.4",
   ["Vital Signs With Entries"] = "2.16.840.1.113883.10.20.22.2.4.1",
   ["Vital Signs Organizer"] = "2.16.840.1.113883.10.20.22.4.26",
   ["Vital Signs Observation"] = "2.16.840.1.113883.10.20.22.4.27",
   ["Problems"] = "2.16.840.1.113883.10.20.22.2.5",
   ["Problems With Entries"] = "2.16.840.1.113883.10.20.22.2.5.1",
   ["Problem Concern Act"] = "2.16.840.1.113883.10.20.22.4.3",
   ["Problem Observation"] = "2.16.840.1.113883.10.20.22.4.4",
   ["Problem Status Observation"] = "2.16.840.1.113883.10.20.22.4.6",
   ["Health Status Observation"] = "2.16.840.1.113883.10.20.22.4.5"
}

cda.codeset.templates.reverse = Reverse(cda.codeset.templates)

-- cda.codeset.cat : ["HL7 AddressUse"] = "2.16.840.1.113883.5.1119"   
cda.codeset.address = {
   Home = 'HP',
   Work = 'WP'
}

cda.codeset.address.reverse = Reverse(cda.codeset.address)

-- cda.codeset.cat : ["HL7 ActStatus"] = "2.16.840.1.113883.5.14"

cda.codeset.status = {
   Completed = "completed",
   Active = "active",
   New = "new",
   Aborted = "aborted"
}

cda.codeset.status.reverse = Reverse(cda.codeset.status)

-- cda.codeset.cat : ["HL7 AdministrativeSex"] = "2.16.840.1.113883.12.1"
cda.codeset.sex = {
   Female = 'F',
   Male='M',
   Unknown='U',
   Other='O'
}

cda.codeset.sex.reverse = Reverse(cda.codeset.sex)

-- cda.codeset.cat : ["Personal Relationship Role"] = "2.16.840.1.113883.1.11.19563"
cda.codeset.personalRelationshipRole = {
    ["aunt"] = "AUNT",
    ["Brother"] = "BRO",
    ["brother-in-law"] = "BROINLAW",
    ["adopted child"] = "CHLDADOPT",
    ["foster child"] = "CHLDFOST",
    ["child in-law"] = "CHLDINLAW",
    ["cousin"] = "COUSN",
    ["natural daughter"] = "DAU",
    ["adopted daughter"] = "DAUADOPT",
    ["Daughter"] = "DAUC",
    ["foster daughter"] = "DAUFOST",
    ["daughter in-law"] = "DAUINLAW",
    ["emergency contact"] = "ECON",
    ["Family Member"] = "FAMMEMB",
    ["Child"] = "- CHILD",
    ["extended family member"] = "EXT",
    ["Immediate family"] = "IMED",
    ["Parent"] = "PRN",
    ["Sibling"] = "SIB",
    ["significant other"] = "SIGOTHR",
    ["domestic partner"] = "DOMPART",
    ["spouse"] = "SPS",
    ["unrelated friend"] = "FRND",
    ["Father"] = "FTH",
    ["father-in-law"] = "FTHINLAW",
    ["great grandfather"] = "GGRFTH",
    ["great grandmother"] = "GGRMTH",
    ["great grandparent"] = "GGRPRN",
    ["Grandfather"] = "GRFTH",
    ["Grandmother"] = "GRMTH",
    ["grandchild"] = "GRNDCHILD",
    ["granddaughter"] = "GRNDDAU",
    ["grandson"] = "GRNDSON",
    ["Grandparent"] = "GRPRN",
    ["Guardian"] = "GUARD",
    ["half-brother"] = "HBRO",
    ["half-sibling"] = "HSIB",
    ["half-sister"] = "HSIS",
    ["husband"] = "HUSB",
    ["Mother"] = "MTH",
    ["mother-in-law"] = "MTHINLAW",
    ["neighbor"] = "NBOR",
    ["natural brother"] = "NBRO",
    ["natural child"] = "NCHILD",
    ["nephew"] = "NEPHEW",
    ["natural father"] = "NFTH",
    ["natural father of fetus"] = "NFTHF",
    ["niece"] = "NIECE",
    ["niece/nephew"] = "NIENEPH",
    ["natural mother"] = "NMTH",
    ["next of kin"] = "NOK",
    ["natural parent"] = "NPRN",
    ["natural sibling"] = "NSIB",
    ["natural sister"] = "NSIS",
    ["Power of attorney"] = "POWATY",
    ["Power of attorney-Personal"] = "POWATYPR",
    ["Power of attorney-Property"] = "POWATYPT",
    ["parent in-law"] = "PRNINLAW",
    ["Roomate"] = "ROOM",
    ["sibling in-law"] = "SIBINLAW",
    ["Sister"] = "SIS",
    ["sister-in-law"] = "SISINLAW",
    ["natural son"] = "SON",
    ["adopted son"] = "SONADOPT",
    ["Son"] = "SONC",
    ["foster son"] = "SONFOST",
    ["son in-law"] = "SONINLAW",
    ["stepbrother"] = "STPBRO",
    ["step child"] = "STPCHLD",
    ["stepdaughter"] = "STPDAU",
    ["stepfather"] = "STPFTH",
    ["stepmother"] = "STPMTH",
    ["step parent"] = "STPPRN",
    ["step sibling"] = "STPSIB",
    ["stepsister"] = "STPSIS",
    ["stepson"] = "STPSON",
    ["substitute decision maker"] = "SUBDM",
    ["uncle"] = "UNCLE",
    ["wife"] = "WIFE"
}

cda.codeset.personalRelationshipRole.reverse = Reverse(cda.codeset.personalRelationshipRole)

-- cda.codeset.cat : LanguageAbilityMode = "2.16.840.1.113883.5.60"
cda.codeset.languageAbilityMode = {
    ["Received signed"] = "RSGN",
    ["Received spoken"] = "RSP",
    ["Expressed written"] = "EWR",
    ["Expressed signed"] = "ESGN",
    ["Expressed spoken"] = "ESP",
    ["Received written"] = "RWR"
}

cda.codeset.languageAbilityMode.reverse = Reverse(cda.codeset.languageAbilityMode)

-- cda.codeset.cat : LanguageAbilityProficiency = "2.16.840.1.113883.5.61",
cda.codeset.proficiencyLevel = {
   ["Excellent"] = "E",
   ["Good"] = "G",
   ["Fair"] = "F",
   ["PoorP"] = "P"
}

cda.codeset.proficiencyLevel.reverse = Reverse(cda.codeset.proficiencyLevel)

-- cda.codeset.cat : ["Provider Codes"] = "2.16.840.1.113883.6.101"
cda.codeset.providerCodes = {
   ["Allopathic &amp; Osteopathic Physicians"] = "200000000X",
   ["Gastroenterologist"] = "207RG0100X"
}

cda.codeset.providerCodes.reverse = Reverse(cda.codeset.providerCodes)

-- cda.codeset.cat : ["HL7 Provider Role"] = "2.16.840.1.113883.12.443"
cda.codeset.providerRoles = {
   ["Consulting ProviderCP"] = "CP",
   ["Primary Care Provider"] = "PP",
   ["Referring Provider"] = "RP"
}

cda.codeset.providerRoles.reverse = Reverse(cda.codeset.providerRoles)

-- cda.codeset.cat : ["HL7 Confidentiality"] = "2.16.840.1.113883.5.25"
cda.codeset.confidentiality = {
   Normal = "N",
   Sensitive = "S",
   Restricted = "R",
   ["Very Restricted"] = "VR",
   ["Consent Directive"] = "CDA"
}

cda.codeset.confidentiality.reverse = Reverse(cda.codeset.confidentiality)

-- cda.codeset.cat : Language = "2.16.840.1.113883.1.11.11526"
cda.codeset.language = {
   ["English - US"] = "en-US"
}

cda.codeset.language.reverse = Reverse(cda.codeset.language)

-- cda.codeset.cat : ["HL7 ParticipationSignature"] = "2.16.840.1.113883.5.89"
cda.codeset.signature = {
   Signed = 'S'
}

cda.codeset.signature.reverse = Reverse(cda.codeset.signature)

-- cda.codeset.cat : SNOMED_CT = "2.16.840.1.113883.6.96"
-- cda.codeset.cat : SNOMED    = "2.16.840.1.113883.6.96"
cda.codeset.snomedCT = {
   ["Mild"] = "255604002",
   ["Moderate to severe"] = "371924009",
   ["Mild to moderate"] = "371923003",
   ["Moderate"] = "6736007",
   ["Colonoscopy"] = "73761001",
   ["Not for resuscitation"] = "304253006",
   ["Propensity to adverse reactions to drug"] = "419511003",
   ["Drug intolerance"] = "59037007",
   ["Inactive"] = "73425007",
   ["Active"] = "55561003",
   ["Nausea"] = "422587007",
   ["Wheezing"] = "56018004",
   ["Hives"] = "247472004",
   ["General Physician"] = "59058001",
   ["Finding"] = "404684003",
   ["Pneumonia"] = "233604007",
   ["Biological father"] = "9947008",
   ["Condition"] = "64572001",
   ["Myocardial infarction"] = "22298006",
   ["Dead"] = "419099009",
   ["Age at onset"] = "445518008",
   ["Diabetes mellitus type 2"] = "44054006",
   ["Caregiver difficulty providing physical care"] = "422615001",
   ["Finding of functional performance and activity"] = "248536006",
   ["Dyspnea"] = "162891007",
   ["Cognitive function finding"] = "373930000",
   ["Memory impairment"] = "386807006",
   ["Aggressive behavior"] = "61372001",
   ["Glasgow Coma score"] = "248241002",
   ["Independently able"] = "371153006",
   ["Immunization education"] = "171044003",
   ["Automatic implantable cardioverter/defibrillator"] = "72506001",
   ["Total hip replacement prosthesis"] = "304120007",
   ["Wheelchair"] = "58938008",
   ["Former smoker"] = "8517006",
   ["Tobacco use and exposure"] = "229819007",
   ["Alcohol consumption"] = "160573003",
   ["Medication drug vehicle"] = "412307009",
   ["Pneumonia"] = "233604007",
   ["Medication instructions"] = "409073007",
   ["Colon part"] = "372174009",
   ["Colonic polyp sample"] = "309226005",
   ["Colonic polypectomy"] = "274025005",
   ["Abdomen and pelvis"] = "416949008",
   ["Colonoscope"] = "90412006",
   ["CBC WO Differential"] = "43789009",
   ["Vital signs"] = "46680005",
   ["Resolved"] = "413322009",
   ["Alive and well"] = "81323004",
   ["Asthma"] = "195967001",
   ["Complaint"] = "409586006"
}
   
cda.codeset.snomedCT.reverse = Reverse(cda.codeset.snomedCT)

-- cda.codeset.cat : LOINC = "2.16.840.1.113883.6.1"
cda.codeset.loinc = {
   ["Advanced Directives"] = "42348-3",
   ["Assessment"] = "51848-0",
   ["Interventions"] = "62387-6",
   ["Allergies, Adverse Reactions, Alerts"] = "48765-2",
   ["Status"] = "33999-4",
   ["History of encounters"] = "46240-8",
   ["History of family member diseases"] = "10157-6",
   ["Functional status assessment"] = "47420-5",
   ["Ambulation"] = "57251-1",
   ["Repetition of Three Words"] = "52731-7",
   ["Three"] = "LA6395-3",
   ["Temporal orientation - current year"] = "52732-5",
   ["Missed by 2-5 years"] = "LA10966-2",
   ["Brief interview for mental status"] = "54614-3",
   ["History of immunizations"] = "11369-6",
   ["History of medical equipment"] = "46264-8",
   ["Treatment plan"] = "18776-5",
   ["Social history"] = "29762-2",
   ["History of medication use"] = "10160-0",
   ["Payer"] = "48768-6",
   ["Payment sources"] = "48768-6",
   ["History of procedures"] = "47519-4",
   ["Results"] = "30954-2",
   ["HGB"] = "30313-1",
   ["WBC"] = "33765-9",
   ["PLT"] = "26515-7",
   ["Vital signs"] = "8716-3",
   ["Height"] = "8302-2",
   ["Patient body weight - measured"] = "3141-9",
   ["Intravascular systolic"] = "8480-6",
   ["Problem list"] = "11450-4",
   ["Health Status"] = "11323-3",
   ["Consultative note"] = "11488-4"
}

cda.codeset.loinc.reverse = Reverse(cda.codeset.loinc)

-- cda.codeset.cat : RxNorm = "2.16.840.1.113883.6.88"
cda.codeset.rxnorm = {
   ["ALLERGENIC EXTRACT, PENICILLIN"] = "314422",
   ["Codeine"] = "2670",
   ["Aspirin"] = "1191",
   ["Proventil HFA"] = "219483",
   ["Proventil 0.09 MG/ACTUAT inhalant solution"] = "573621",
   ["Aerosol"] = "324049"
}

cda.codeset.rxnorm.reverse = Reverse(cda.codeset.rxnorm)

-- cda.codeset.cat : ["HL7 ActCode"] = "2.16.840.1.113883.5.4"
cda.codeset.act = {
   ["Assertion"] = "ASSERTION",
   ["Severity Observation"] = "SEV",
   ["Ambulatory"] = "AMB"
}

cda.codeset.act.reverse = Reverse(cda.codeset.act)

-- cda.codeset.cat : ["HL7 Act No Immunization Reason"] = "2.16.840.1.113883.5.8"
cda.codeset.actNoImmunization = {
   ["Patient Objection"] = "PATOBJ"
}

cda.codeset.actNoImmunization.reverse = Reverse(cda.codeset.actNoImmunization)

-- cda.codeset.cat : CPT = "2.16.840.1.113883.6.12"
cda.codeset.cpt = {
   ["Office outpatient visit 15 minutes"] = "99213"
}

cda.codeset.cpt.reverse = Reverse(cda.codeset.cpt)

-- cda.codeset.cat : ObservationInterpretation = "2.16.840.1.113883.5.83"
cda.codeset.interpretation = {
   Suceptible = "S",
   Normal = "N",
   Better = "B",
   Low = "L",
   ["Low alert"] = "LL",
   High = "H",
   ["High alert"] = "HH"
}

cda.codeset.interpretation.reverse = Reverse(cda.codeset.interpretation)

-- cda.codeset.cat : ["Healthcare Service Location"] = "2.16.840.1.113883.6.259"
cda.codeset.healthcareServiceLocation = {
   ["Urgent Care Center"] = "1160-1",
   ["Gastroenterology Clinic"] = "1118-9"   
}

cda.codeset.healthcareServiceLocation.reverse = Reverse(cda.codeset.healthcareServiceLocation)

-- cda.codeset.cat : ICF = "2.16.840.1.113883.6.254"
cda.codeset.icf = {
   ["Self-Care"] = "d5",
   ["Communication"] = "d3"
}

cda.codeset.icf.reverse = Reverse(cda.codeset.icf)

-- cda.codeset.cat : ["HL7 Advance Directive Type"] = "2.16.840.1.113883.1.11.20.2"
cda.codeset.advancedDirectivesTypes = {
   ["Antibiotics"] = "281789004",
   ["CPR"] = "89666000",
   ["IV Fluid and Support"] = "225204009",
   ["Intubation"] = "52765003",
   ["Life Support"] = "78823007",
   ["Resuscitation"] = "304251008"
}

cda.codeset.advancedDirectivesTypes.reverse = Reverse(cda.codeset.advancedDirectivesTypes)

-- cda.codeset.cat : ["NCI - FDA RouteOfAdministration"] = "2.16.840.1.113883.3.26.1.1"
cda.codeset.nci = {
   ["Intramuscular injection"] = "C28161",
   ["Respiratory (Inhalation)"] = "C38216",
   ["Inhalant"] = "C42944"
}

cda.codeset.nci.reverse = Reverse(cda.codeset.nci)

-- cda.codeset.cat : CVX = "2.16.840.1.113883.12.292"
cda.codeset.cvx = {
   ["Influenza virus vaccine"] = "88",
   ["Influenza, seasonal, injectable"] = "141",
   ["Pneumococcal polysaccharide vaccine"] = "33",
   ["Pneumococcal NOS"] = "109",
   ["Tetanus and diphtheria toxoids - preservative free vaccine"] = "103",
   ["Tetanus and diphtheria toxoids - preservative free"] = "09"
}

cda.codeset.cvx.reverse = Reverse(cda.codeset.cvx)

-- cda.codeset.cat : ["HL7 EntityNameUse"] = "2.16.840.1.113883.5.45"
cda.codeset.nameUses = {
    ["License"] = "C",
    ["Indigenous/Tribal"] = "I",
    ["Legal"] = "L",
    ["Pseudonym"] = "P",
    ["Artist/Stage"] = "A",
    ["Religious"] = "R",
    ["Search"] = "SRCH",
    ["Phonetic"] = "PHON",
    ["Soundex"] = "SNDX",
    ["Alphabetic"] = "ABC",
    ["Syllabic"] = "SYL",
    ["Ideographic"] = "IDE"
}

cda.codeset.nameUses.reverse = Reverse(cda.codeset.nameUses)

-- cda.codeset.cat : ["HL7 Role Class"] = "2.16.840.1.113883.5.111"
cda.codeset.roleClass = {
  ["access"] = "ACCESS",
  ["active ingredient"] = "ACTI",
  ["ac"] = "ACTIB",
  ["active ingredient - moiety is basis of strength"] = "ACTIM",
  ["active ingredient - reference substance is basis of strength"] = "ACTIR",
  ["active moiety"] = "ACTM",
  ["additive"] = "ADTV",
  ["Administerable Material"] = "ADMM",
  ["affiliate"] = "AFFL",
  ["agent"] = "AGNT",
  ["aliquot"] = "ALQT",
  ["assigned entity"] = "ASSIGNED",
  ["base"] = "BASE",
  ["birthplace"] = "BIRTHPL",
  ["caregiver"] = "CAREGIVER",
  ["Case Subject"] = "CASEBJ",
  ["child"] = "CHILD",
  ["citizen"] = "CIT",
  ["claimant"] = "CLAIM",
  ["clinical research investigator"] = "CRINV",
  ["clinical research sponsor"] = "CRSPNSR",
  ["color additive"] = "COLR",
  ["commissioning party"] = "COMPAR",
  ["contact"] = "CON",
  ["content"] = "CONT",
  ["coverage sponsor"] = "SPNSR",
  ["covered party"] = "COVPTY",
  ["credentialed entity"] = "CRED",
  ["dedicated service delivery location"] = "DSDLOC",
  ["dependent"] = "DEPEN",
  ["distributed material"] = "DST",
  ["emergency contact"] = "ECON",
  ["employee"] = "EMP",
  ["equivalent entity"] = "EQUIV",
  ["exposed entity"] = "EXPR",
  ["exposure agent carrier"] = "EXPAGTCAR",
  ["exposure vector"] = "EXPVECTOR",
  ["flavor additive"] = "FLVR",
  ["fomite"] = "FOMITE",
  ["guarantor"] = "GUAR",
  ["guardian"] = "GUARD",
  ["has generalization"] = "GEN",
  ["has generic"] = "GRIC",
  ["health chart"] = "HLTHCHRT",
  ["healthcare provider"] = "PROV",
  ["held entity"] = "HLD",
  ["identified entity"] = "IDENT",
  ["inactive ingredient"] = "IACT",
  ["incidental service delivery location"] = "ISDLOC",
  ["individual"] = "INDIV",
  ["ingredient"] = "INGR",
  ["instance"] = "INST",
  ["Investigation Subject"] = "INVSBJ",
  ["invoice payor"] = "PAYOR",
  ["isolate"] = "ISLT",
  ["licensed entity"] = "LIC",
  ["located entity"] = "LOCE",
  ["maintained entity"] = "MNT",
  ["manufactured product"] = "MANU",
  ["member"] = "MBR",
  ["military person"] = "MIL",
  ["named insured"] = "NAMED",
  ["next of kin"] = "NOK",
  ["notary public"] = "NOT",
  ["nurse"] = "NURS",
  ["nurse practitioner"] = "NURPRAC",
  ["owned entity"] = "OWN",
  ["part"] = "PART",
  ["patient"] = "PAT",
  ["payee"] = "PAYEE",
  ["personal relationship"] = "PRS",
  ["physician"] = "PHYS",
  ["physician assistant"] = "PA",
  ["place of death"] = "DEATHPLC",
  ["policy holder"] = "POLHOLD",
  ["preservative"] = "PRSV",
  ["program eligible"] = "PROG",
  ["qualified entity"] = "QUAL",
  ["regulated product"] = "RGPR",
  ["research subject"] = "RESBJ",
  ["retailed material"] = "RET",
  ["role"] = "ROL",
  ["RoleClassAssociative"] = "_RoleClassAssociative",
  ["RoleClassMutualRelationship"] = "_RoleClassMutualRelationship",
  ["RoleClassOntological"] = "_RoleClassOntological",
  ["RoleClassPartitive"] = "_RoleClassPartitive",
  ["RoleClassPassive"] = "_RoleClassPassive",
  ["RoleClassRelationshipFormal"] = "_RoleClassRelationshipFormal",
  ["same"] = "SAME",
  ["self"] = "SELF",
  ["service delivery location"] = "SDLOC",
  ["signing authority or officer"] = "SGNOFF",
  ["specimen"] = "SPEC",
  ["stabilizer"] = "STBL",
  ["stored entity"] = "STOR",
  ["student"] = "STD",
  ["subscriber"] = "SUBSCR",
  ["subsumed by"] = "SUBY",
  ["subsumer"] = "SUBS",
  ["territory of authority"] = "TERR",
  ["therapeutic agent"] = "THER",
  ["underwriter"] = "UNDWRT",
  ["used entity"] = "USED",
  ["warranted product"] = "WRTE"
}

cda.codeset.roleClass.reverse = Reverse(cda.codeset.roleClass)
      
-- cda.codeset.cat : ["HL7 Act Priority"] = "2.16.840.1.113883.5.7"
cda.codeset.actPriority = {
  ["Callback results"] = "CR"
}

cda.codeset.actPriority.reverse = Reverse(cda.codeset.actPriority)

-- cda.codeset.cat : ["HL7 Act Class"] = "2.16.840.1.113883.5.6"
cda.codeset.actClass = {
  ["act"] = "ACT",
  ["accommodation"] = "ACCM",
  ["account"] = "ACCT",
  ["accession"] = "ACSN",
  ["financial adjudication"] = "ADJUD",
  ["control act"] = "CACT",
  ["action"] = "ACTN",
  ["information"] = "INFO",
  ["state transition control"] = "STC",
  ["contract"] = "CNTRCT",
  ["financial contract"] = "FCNTRCT",
  ["coverage"] = "COV",
  ["consent"] = "CONS",
  ["container registration"] = "CONTREG",
  ["clinical trial timepoint event"] = "CTTEVENT",
  ["disciplinary action"] = "DISPACT",
  ["exposure"] = "EXPOS",
  ["acquisition exposure"] = "AEXPOS",
  ["transmission exposure"] = "TEXPOS",
  ["incident"] = "INC",
  ["inform"] = "INFRM",
  ["invoice element"] = "INVE",
  ["working list"] = "LIST",
  ["monitoring program"] = "MPROT",
  ["observation"] = "OBS",
  ["detected issue"] = "ALRT",
  ["battery"] = "BATTERY",
  ["clinical trial"] = "CLNTRL",
  ["Condition Node"] = "CNOD",
  ["concern"] = "CONC",
  ["Condition"] = "COND",
  ["public health case"] = "CASE",
  ["outbreak"] = "OUTB",
  ["diagnostic image"] = "DGIMG",
  ["genomic observation"] = "GEN",
  ["determinant peptide"] = "DETPOL",
  ["expression level"] = "EXP",
  ["locus"] = "LOC",
  ["phenotype"] = "PHN",
  ["polypeptide"] = "POL",
  ["bio sequence"] = "SEQ",
  ["bio sequence variation"] = "SEQVAR",
  ["investigation"] = "INVSTG",
  ["observation series"] = "OBSSER",
  ["correlated observation sequences"] = "OBSCOR",
  ["position"] = "POS",
  ["position accuracy"] = "POSACC",
  ["position coordinate"] = "POSCOORD",
  ["specimen observation"] = "SPCOBS",
  ["Verification"] = "VERIF",
  ["ActClassROI"] = "_ActClassROI",
  ["bounded ROI"] = "ROIBND",
  ["overlay ROI"] = "ROIOVL",
  ["subject physical position"] = "_SubjectPhysicalPosition",
  ["subject body position"] = "_SubjectBodyPosition",
  ["left lateral decubitus"] = "LLD",
  ["prone"] = "PRN",
  ["right lateral decubitus"] = "RLD",
  ["Semi-Fowler's"] = "SFWL",
  ["sitting"] = "SIT",
  ["standing"] = "STN",
  ["supine"] = "SUP",
  ["reverse trendelenburg"] = "RTRD",
  ["trendelenburg"] = "TRD",
  ["care provision"] = "PCPR",
  ["encounter"] = "ENC",
  ["policy"] = "POLICY",
  ["jurisdictional policy"] = "JURISPOL",
  ["organizational policy"] = "ORGPOL",
  ["scope of practice policy"] = "SCOPOL",
  ["standard of practice policy"] = "STDPOL",
  ["procedure"] = "PROC",
  ["substance administration"] = "SBADM",
  ["Substance Extraction"] = "SBEXT",
  ["Specimen Collection"] = "SPECCOLLECT",
  ["registration"] = "REG",
  ["review"] = "REV",
  ["specimen treatment"] = "SPCTRT",
  ["supply"] = "SPLY",
  ["diet"] = "DIET",
  ["storage"] = "STORE",
  ["Substitution"] = "SUBST",
  ["transfer"] = "TRFR",
  ["transportation"] = "TRNS",
  ["financial transaction"] = "XACT",
  ["record organizer"] = "_ActClassRecordOrganizer",
  ["composition"] = "COMPOSITION",
  ["document"] = "DOC",
  ["clinical document"] = "DOCCLIN",
  ["CDA Level One clinical document"] = "CDALVLONE",
  ["record container"] = "CONTAINER",
  ["category"] = "CATEGORY",
  ["document body"] = "DOCBODY",
  ["document section"] = "DOCSECT",
  ["topic"] = "TOPIC",
  ["extract"] = "EXTRACT",
  ["electronic health record"] = "EHR",
  ["folder"] = "FOLDER",
  ["grouper"] = "GROUPER",
  ["Cluster"] = "CLUSTER"
}

cda.codeset.actClass.reverse = Reverse(cda.codeset.actClass)

-- cda.codeset.cat : ["HL7 Marital status"] = "2.16.840.1.113883.5.2"
cda.codeset.marriage = {
  ["Annulled"]='A',
  ["Divorced"]='D',
  ["Domestic partner"]='T',
  ["Interlocutory"]='I',
  ["Legally Separated"]='L',
  ["Married"]='M',  
  ["Never Married"]='S',
  ["Polygamous"]='P',
  ["Widowed"]='W',
}

cda.codeset.marriage.reverse = Reverse(cda.codeset.marriage)

-- cda.codeset.cat : ["ReligiousAffiliation"] = "2.16.840.1.113883.5.1076"
cda.codeset.religion = {
   ["Adventist"]=1001,
   ["African Religions"]=1002,
   ["Afro-Caribbean Religions"]=1003,
   ["Agnosticism"]=1004,
   ["Anglican"]=1005,
   ["Animism"]=1006,
   ["Atheism"]=1007,
   ["Babi & Baha'I faiths"]=1008,
   ["Baptist"]=1009,
   ["Bon"]=1010,
   ["Cao Dai"]=1011,
   ["Celticism"]=1012,
   ["Christian (non-Catholic, non-specific)"]=1013,
   ["Confucianism"]=1014,
   ["Cyberculture Religions"]=1015,
   ["Divination"]=1016,
   ["Fourth Way"]=1017,
   ["Free Daism"]=1018,
   ["Gnosis"]=1019,
   ["Hinduism"]=1020,
   ["Humanism"]=1021,
   ["Independent"]=1022,
   ["Islam"]=1023,
   ["Jainism"]=1024,
   ["Jehovah's Witnesses"]=1025,
   ["Judaism"]=1026,
   ["Latter Day Saints"]=1027,
   ["Lutheran"]=1028,
   ["Mahayana"]=1029,
   ["Meditation"]=1030,
   ["Messianic Judaism"]=1031,
   ["Mitraism"]=1032,
   ["New Age"]=1033,
   ["non-Roman Catholic"]=1034,
   ["Occult"]=1035,
   ["Orthodox"]=1036,
   ["Paganism"]=1037,
   ["Pentecostal"]=1038,
   ["Process, The"]=1039,
   ["Reformed/Presbyterian"]=1040,
   ["Roman Catholic Church"]=1041,
   ["Satanism"]=1042,
   ["Scientology"]=1043,
   ["Shamanism"]=1044,
   ["Shiite (Islam)"]=1045,
   ["Shinto"]=1046,
   ["Sikism"]=1047,
   ["Spiritualism"]=1048,
   ["Sunni (Islam)"]=1049,
   ["Taoism"]=1050,
   ["Theravada"]=1051,
   ["Unitarian-Universalism"]=1052,
   ["Universal Life Church"]=1053,
   ["Vajrayana (Tibetan)"]=1054,
   ["Veda"]=1055,
   ["Voodoo"]=1056,
   ["Wicca"]=1057,
   ["Yaohushua"]=1058,
   ["Zen Buddhism"]=1059,
   ["Zoroastrianism"]=1060,
   ["Assembly of God"]=1061,
   ["Brethren"]=1062,
   ["Christian Scientist"]=1063,
   ["Church of Christ"]=1064,
   ["Church of God"]=1065,
   ["Congregational"]=1066,
   ["Disciples of Christ"]=1067,
   ["Eastern Orthodox"]=1068,
   ["Episcopalian"]=1069,
   ["Evangelical Covenant"]=1070,
   ["Friends"]=1071,
   ["Full Gospel"]=1072,
   ["Methodist"]=1073,
   ["Native American"]=1074,
   ["Nazarene"]=1075,
   ["Presbyterian"]=1076,
   ["Protestant"]=1077,
   ["Protestant, No Denomination"]=1078,
   ["Reformed"]=1079,
   ["Salvation Army"]=1080,
   ["Unitarian Universalist"]=1081,
   ["United Church of Christ"]=1082,
}

cda.codeset.religion.reverse = Reverse(cda.codeset.religion)

-- cda.codeset.cat : ["HL7 Race and Ethnicity"] = "2.16.840.1.113883.6.238"
cda.codeset.race = {
   ["Abenaki"]="1006-6",
   ["Absentee Shawnee"]="1579-2",
   ["Acoma"]="1490-2",
   ["Afghanistani"]="2126-1",
   ["African"]="2060-2",
   ["African American"]="2058-6",
   ["Agdaagux"]="1994-3",
   ["Agua Caliente"]="1212-0",
   ["Agua Caliente Cahuilla"]="1045-4",
   ["Ahtna"]="1740-0",
   ["Ak-Chin"]="1654-3",
   ["Akhiok"]="1993-5",
   ["Akiachak"]="1897-8",
   ["Akiak"]="1898-6",
   ["Akutan"]="2007-3",
   ["Alabama Coushatta"]="1187-4",
   ["Alabama Creek"]="1194-0",
   ["Alabama Quassarte"]="1195-7",
   ["Alakanuk"]="1899-4",
   ["Alamo Navajo"]="1383-9",
   ["Alanvik"]="1744-2",
   ["Alaska Indian"]="1737-6",
   ["Alaska Native"]="1735-0",
   ["Alaskan Athabascan"]="1739-2",
   ["Alatna"]="1741-8",
   ["Aleknagik"]="1900-0",
   ["Aleut"]="1966-1",
   ["Aleut Corporation"]="2008-1",
   ["Aleutian"]="2009-9",
   ["Aleutian Islander"]="2010-7",
   ["Alexander"]="1742-6",
   ["Algonquian"]="1008-2",
   ["Allakaket"]="1743-4",
   ["Allen Canyon"]="1671-7",
   ["Alpine"]="1688-1",
   ["Alsea"]="1392-0",
   ["Alutiiq Aleut"]="1968-7",
   ["Ambler"]="1845-7",
   ["American Indian"]="1004-1",
   ["American Indian or Alaska Native"]="1002-5",
   ["Anaktuvuk"]="1846-5",
   ["Anaktuvuk Pass"]="1847-3",
   ["Andreafsky"]="1901-8",
   ["Angoon"]="1814-3",
   ["Aniak"]="1902-6",
   ["Anvik"]="1745-9",
   ["Apache"]="1010-8",
   ["Arab"]="2129-5",
   ["Arapaho"]="1021-5",
   ["Arctic"]="1746-7",
   ["Arctic Slope Corporation"]="1849-9",
   ["Arctic Slope Inupiat"]="1848-1",
   ["Arikara"]="1026-4",
   ["Arizona Tewa"]="1491-0",
   ["Armenian"]="2109-7",
   ["Aroostook"]="1366-4",
   ["Asian"]="2028-9",
   ["Asian Indian"]="2029-7",
   ["Assiniboine"]="1028-0",
   ["Assiniboine Sioux"]="1030-6",
   ["Assyrian"]="2119-6",
   ["Atka"]="2011-5",
   ["Atmautluak"]="1903-4",
   ["Atqasuk"]="1850-7",
   ["Atsina"]="1265-8",
   ["Attacapa"]="1234-4",
   ["Augustine"]="1046-2",
   ["Bad River"]="1124-7",
   ["Bahamian"]="2067-7",
   ["Bangladeshi"]="2030-5",
   ["Bannock"]="1033-0",
   ["Barbadian"]="2068-5",
   ["Barrio Libre"]="1712-9",
   ["Barrow"]="1851-5",
   ["Battle Mountain"]="1587-5",
   ["Bay Mills Chippewa"]="1125-4",
   ["Beaver"]="1747-5",
   ["Belkofski"]="2012-3",
   ["Bering Straits Inupiat"]="1852-3",
   ["Bethel"]="1904-2",
   ["Bhutanese"]="2031-3",
   ["Big Cypress"]="1567-7",
   ["Bill Moore's Slough"]="1905-9",
   ["Biloxi"]="1235-1",
   ["Birch Creek"]="1748-3",
   ["Bishop"]="1417-5",
   ["Black"]="2056-0",
   ["Black or African American"]="2054-5",
   ["Blackfeet"]="1035-5",
   ["Blackfoot Sioux"]="1610-5",
   ["Bois Forte"]="1126-2",
   ["Botswanan"]="2061-0",
   ["Brevig Mission"]="1853-1",
   ["Bridgeport"]="1418-3",
   ["Brighton"]="1568-5",
   ["Bristol Bay Aleut"]="1972-9",
   ["Bristol Bay Yupik"]="1906-7",
   ["Brotherton"]="1037-1",
   ["Brule Sioux"]="1611-3",
   ["Buckland"]="1854-9",
   ["Burmese"]="2032-1",
   ["Burns Paiute"]="1419-1",
   ["Burt Lake Band"]="1039-7",
   ["Burt Lake Chippewa"]="1127-0",
   ["Burt Lake Ottawa"]="1412-6",
   ["Cabazon"]="1047-0",
   ["Caddo"]="1041-3",
   ["Cahto"]="1054-6",
   ["Cahuilla"]="1044-7",
   ["California Tribes"]="1053-8",
   ["Calista Yupik"]="1907-5",
   ["Cambodian"]="2033-9",
   ["Campo"]="1223-7",
   ["Canadian and Latin American Indian"]="1068-6",
   ["Canadian Indian"]="1069-4",
   ["Canoncito Navajo"]="1384-7",
   ["Cantwell"]="1749-1",
   ["Capitan Grande"]="1224-5",
   ["Carolinian"]="2092-5",
   ["Carson"]="1689-9",
   ["Catawba"]="1076-9",
   ["Cayuga"]="1286-4",
   ["Cayuse"]="1078-5",
   ["Cedarville"]="1420-9",
   ["Celilo"]="1393-8",
   ["Central American Indian"]="1070-2",
   ["Central Council of Tlingit and Haida Tribes"]="1815-0",
   ["Central Pomo"]="1465-4",
   ["Chalkyitsik"]="1750-9",
   ["Chamorro"]="2088-3",
   ["Chefornak"]="1908-3",
   ["Chehalis"]="1080-1",
   ["Chemakuan"]="1082-7",
   ["Chemehuevi"]="1086-8",
   ["Chenega"]="1985-1",
   ["Cherokee"]="1088-4",
   ["Cherokee Alabama"]="1089-2",
   ["Cherokee Shawnee"]="1100-7",
   ["Cherokees of Northeast Alabama"]="1090-0",
   ["Cherokees of Southeast Alabama"]="1091-8",
   ["Chevak"]="1909-1",
   ["Cheyenne"]="1102-3",
   ["Cheyenne River Sioux"]="1612-1",
   ["Cheyenne-Arapaho"]="1106-4",
   ["Chickahominy"]="1108-0",
   ["Chickaloon"]="1751-7",
   ["Chickasaw"]="1112-2",
   ["Chignik"]="1973-7",
   ["Chignik Lagoon"]="2013-1",
   ["Chignik Lake"]="1974-5",
   ["Chilkat"]="1816-8",
   ["Chilkoot"]="1817-6",
   ["Chimariko"]="1055-3",
   ["Chinese"]="2034-7",
   ["Chinik"]="1855-6",
   ["Chinook"]="1114-8",
   ["Chippewa"]="1123-9",
   ["Chippewa Cree"]="1150-2",
   ["Chiricahua"]="1011-6",
   ["Chistochina"]="1752-5",
   ["Chitimacha"]="1153-6",
   ["Chitina"]="1753-3",
   ["Choctaw"]="1155-1",
   ["Chuathbaluk"]="1910-9",
   ["Chugach Aleut"]="1984-4",
   ["Chugach Corporation"]="1986-9",
   ["Chukchansi"]="1718-6",
   ["Chumash"]="1162-7",
   ["Chuukese"]="2097-4",
   ["Circle"]="1754-1",
   ["Citizen Band Potawatomi"]="1479-5",
   ["Clark's Point"]="1911-7",
   ["Clatsop"]="1115-5",
   ["Clear Lake"]="1165-0",
   ["Clifton Choctaw"]="1156-9",
   ["Coast Miwok"]="1056-1",
   ["Coast Yurok"]="1733-5",
   ["Cochiti"]="1492-8",
   ["Cocopah"]="1725-1",
   ["Coeur D'Alene"]="1167-6",
   ["Coharie"]="1169-2",
   ["Colorado River"]="1171-8",
   ["Columbia"]="1394-6",
   ["Columbia River Chinook"]="1116-3",
   ["Colville"]="1173-4",
   ["Comanche"]="1175-9",
   ["Cook Inlet"]="1755-8",
   ["Coos"]="1180-9",
   ["Coos, Lower Umpqua, Siuslaw"]="1178-3",
   ["Copper Center"]="1756-6",
   ["Copper River"]="1757-4",
   ["Coquilles"]="1182-5",
   ["Costanoan"]="1184-1",
   ["Council"]="1856-4",
   ["Coushatta"]="1186-6",
   ["Cow Creek Umpqua"]="1668-3",
   ["Cowlitz"]="1189-0",
   ["Craig"]="1818-4",
   ["Cree"]="1191-6",
   ["Creek"]="1193-2",
   ["Croatan"]="1207-0",
   ["Crooked Creek"]="1912-5",
   ["Crow"]="1209-6",
   ["Crow Creek Sioux"]="1613-9",
   ["Cupeno"]="1211-2",
   ["Cuyapaipe"]="1225-2",
   ["Dakota Sioux"]="1614-7",
   ["Deering"]="1857-2",
   ["Delaware"]="1214-6",
   ["Diegueno"]="1222-9",
   ["Digger"]="1057-9",
   ["Dillingham"]="1913-3",
   ["Dominica Islander"]="2070-1",
   ["Dominican"]="2069-3",
   ["Dot Lake"]="1758-2",
   ["Douglas"]="1819-2",
   ["Doyon"]="1759-0",
   ["Dresslerville"]="1690-7",
   ["Dry Creek"]="1466-2",
   ["Duck Valley"]="1603-0",
   ["Duckwater"]="1588-3",
   ["Duwamish"]="1519-8",
   ["Eagle"]="1760-8",
   ["Eastern Cherokee"]="1092-6",
   ["Eastern Chickahominy"]="1109-8",
   ["Eastern Creek"]="1196-5",
   ["Eastern Delaware"]="1215-3",
   ["Eastern Muscogee"]="1197-3",
   ["Eastern Pomo"]="1467-0",
   ["Eastern Shawnee"]="1580-0",
   ["Eastern Tribes"]="1233-6",
   ["Echota Cherokee"]="1093-4",
   ["Eek"]="1914-1",
   ["Egegik"]="1975-2",
   ["Egyptian"]="2120-4",
   ["Eklutna"]="1761-6",
   ["Ekuk"]="1915-8",
   ["Ekwok"]="1916-6",
   ["Elim"]="1858-0",
   ["Elko"]="1589-1",
   ["Ely"]="1590-9",
   ["Emmonak"]="1917-4",
   ["English"]="2110-5",
   ["English Bay"]="1987-7",
   ["Eskimo"]="1840-8",
   ["Esselen"]="1250-0",
   ["Ethiopian"]="2062-8",
   ["Etowah Cherokee"]="1094-2",
   ["European"]="2108-9",
   ["Evansville"]="1762-4",
   ["Eyak"]="1990-1",
   ["Fallon"]="1604-8",
   ["False Pass"]="2015-6",
   ["Fijian"]="2101-4",
   ["Filipino"]="2036-2",
   ["Flandreau Santee"]="1615-4",
   ["Florida Seminole"]="1569-3",
   ["Fond du Lac"]="1128-8",
   ["Forest County"]="1480-3",
   ["Fort Belknap"]="1252-6",
   ["Fort Berthold"]="1254-2",
   ["Fort Bidwell"]="1421-7",
   ["Fort Hall"]="1258-3",
   ["Fort Independence"]="1422-5",
   ["Fort McDermitt"]="1605-5",
   ["Fort Mcdowell"]="1256-7",
   ["Fort Peck"]="1616-2",
   ["Fort Peck Assiniboine Sioux"]="1031-4",
   ["Fort Sill Apache"]="1012-4",
   ["Fort Yukon"]="1763-2",
   ["French"]="2111-3",
   ["French American Indian"]="1071-0",
   ["Gabrieleno"]="1260-9",
   ["Gakona"]="1764-0",
   ["Galena"]="1765-7",
   ["Gambell"]="1892-9",
   ["Gay Head Wampanoag"]="1680-8",
   ["Georgetown (Eastern Tribes)"]="1236-9",
   ["Georgetown (Yupik-Eskimo)"]="1962-0",
   ["German"]="2112-1",
   ["Gila Bend"]="1655-0",
   ["Gila River Pima-Maricopa"]="1457-1",
   ["Golovin"]="1859-8",
   ["Goodnews Bay"]="1918-2",
   ["Goshute"]="1591-7",
   ["Grand Portage"]="1129-6",
   ["Grand Ronde"]="1262-5",
   ["Grand Traverse Band of Ottawa/Chippewa"]="1130-4",
   ["Grayling"]="1766-5",
   ["Greenland Eskimo"]="1842-4",
   ["Gros Ventres"]="1264-1",
   ["Guamanian"]="2087-5",
   ["Guamanian or Chamorro"]="2086-7",
   ["Gulkana"]="1767-3",
   ["Haida"]="1820-0",
   ["Haitian"]="2071-9",
   ["Haliwa"]="1267-4",
   ["Hannahville"]="1481-1",
   ["Havasupai"]="1726-9",
   ["Healy Lake"]="1768-1",
   ["Hidatsa"]="1269-0",
   ["Hmong"]="2037-0",
   ["Ho-chunk"]="1697-2",
   ["Hoh"]="1083-5",
   ["Hollywood Seminole"]="1570-1",
   ["Holy Cross"]="1769-9",
   ["Hoonah"]="1821-8",
   ["Hoopa"]="1271-6",
   ["Hoopa Extension"]="1275-7",
   ["Hooper Bay"]="1919-0",
   ["Hopi"]="1493-6",
   ["Houma"]="1277-3",
   ["Hualapai"]="1727-7",
   ["Hughes"]="1770-7",
   ["Huron Potawatomi"]="1482-9",
   ["Huslia"]="1771-5",
   ["Hydaburg"]="1822-6",
   ["Igiugig"]="1976-0",
   ["Iliamna"]="1772-3",
   ["Illinois Miami"]="1359-9",
   ["Inaja-Cosmit"]="1279-9",
   ["Inalik Diomede"]="1860-6",
   ["Indian Township"]="1442-3",
   ["Indiana Miami"]="1360-7",
   ["Indonesian"]="2038-8",
   ["Inupiaq"]="1861-4",
   ["Inupiat Eskimo"]="1844-0",
   ["Iowa"]="1281-5",
   ["Iowa of Kansas-Nebraska"]="1282-3",
   ["Iowa of Oklahoma"]="1283-1",
   ["Iowa Sac and Fox"]="1552-9",
   ["Iqurmuit (Russian Mission)"]="1920-8",
   ["Iranian"]="2121-2",
   ["Iraqi"]="2122-0",
   ["Irish"]="2113-9",
   ["Iroquois"]="1285-6",
   ["Isleta"]="1494-4",
   ["Israeili"]="2127-9",
   ["Italian"]="2114-7",
   ["Ivanof Bay"]="1977-8",
   ["Iwo Jiman"]="2048-7",
   ["Jamaican"]="2072-7",
   ["Jamestown"]="1313-6",
   ["Japanese"]="2039-6",
   ["Jemez"]="1495-1",
   ["Jena Choctaw"]="1157-7",
   ["Jicarilla Apache"]="1013-2",
   ["Juaneno"]="1297-1",
   ["Kaibab"]="1423-3",
   ["Kake"]="1823-4",
   ["Kaktovik"]="1862-2",
   ["Kalapuya"]="1395-3",
   ["Kalispel"]="1299-7",
   ["Kalskag"]="1921-6",
   ["Kaltag"]="1773-1",
   ["Karluk"]="1995-0",
   ["Karuk"]="1301-1",
   ["Kasaan"]="1824-2",
   ["Kashia"]="1468-8",
   ["Kasigluk"]="1922-4",
   ["Kathlamet"]="1117-1",
   ["Kaw"]="1303-7",
   ["Kawaiisu"]="1058-7",
   ["Kawerak"]="1863-0",
   ["Kenaitze"]="1825-9",
   ["Keres"]="1496-9",
   ["Kern River"]="1059-5",
   ["Ketchikan"]="1826-7",
   ["Keweenaw"]="1131-2",
   ["Kialegee"]="1198-1",
   ["Kiana"]="1864-8",
   ["Kickapoo"]="1305-2",
   ["Kikiallus"]="1520-6",
   ["King Cove"]="2014-9",
   ["King Salmon"]="1978-6",
   ["Kiowa"]="1309-4",
   ["Kipnuk"]="1923-2",
   ["Kiribati"]="2096-6",
   ["Kivalina"]="1865-5",
   ["Klallam"]="1312-8",
   ["Klamath"]="1317-7",
   ["Klawock"]="1827-5",
   ["Kluti Kaah"]="1774-9",
   ["Knik"]="1775-6",
   ["Kobuk"]="1866-3",
   ["Kodiak"]="1996-8",
   ["Kokhanok"]="1979-4",
   ["Koliganek"]="1924-0",
   ["Kongiganak"]="1925-7",
   ["Koniag Aleut"]="1992-7",
   ["Konkow"]="1319-3",
   ["Kootenai"]="1321-9",
   ["Korean"]="2040-4",
   ["Kosraean"]="2093-3",
   ["Kotlik"]="1926-5",
   ["Kotzebue"]="1867-1",
   ["Koyuk"]="1868-9",
   ["Koyukuk"]="1776-4",
   ["Kwethluk"]="1927-3",
   ["Kwigillingok"]="1928-1",
   ["Kwiguk"]="1869-7",
   ["La Jolla"]="1332-6",
   ["La Posta"]="1226-0",
   ["Lac Courte Oreilles"]="1132-0",
   ["Lac du Flambeau"]="1133-8",
   ["Lac Vieux Desert Chippewa"]="1134-6",
   ["Laguna"]="1497-7",
   ["Lake Minchumina"]="1777-2",
   ["Lake Superior"]="1135-3",
   ["Lake Traverse Sioux"]="1617-0",
   ["Laotian"]="2041-2",
   ["Larsen Bay"]="1997-6",
   ["Las Vegas"]="1424-1",
   ["Lassik"]="1323-5",
   ["Lebanese"]="2123-8",
   ["Leech Lake"]="1136-1",
   ["Lenni-Lenape"]="1216-1",
   ["Levelock"]="1929-9",
   ["Liberian"]="2063-6",
   ["Lime"]="1778-0",
   ["Lipan Apache"]="1014-0",
   ["Little Shell Chippewa"]="1137-9",
   ["Lone Pine"]="1425-8",
   ["Long Island"]="1325-0",
   ["Los Coyotes"]="1048-8",
   ["Lovelock"]="1426-6",
   ["Lower Brule Sioux"]="1618-8",
   ["Lower Elwha"]="1314-4",
   ["Lower Kalskag"]="1930-7",
   ["Lower Muscogee"]="1199-9",
   ["Lower Sioux"]="1619-6",
   ["Lower Skagit"]="1521-4",
   ["Luiseno"]="1331-8",
   ["Lumbee"]="1340-9",
   ["Lummi"]="1342-5",
   ["Machis Lower Creek Indian"]="1200-5",
   ["Madagascar"]="2052-9",
   ["Maidu"]="1344-1",
   ["Makah"]="1348-2",
   ["Malaysian"]="2042-0",
   ["Maldivian"]="2049-5",
   ["Malheur Paiute"]="1427-4",
   ["Maliseet"]="1350-8",
   ["Mandan"]="1352-4",
   ["Manley Hot Springs"]="1780-6",
   ["Manokotak"]="1931-5",
   ["Manzanita"]="1227-8",
   ["Mariana Islander"]="2089-1",
   ["Maricopa"]="1728-5",
   ["Marshall"]="1932-3",
   ["Marshallese"]="2090-9",
   ["Marshantucket Pequot"]="1454-8",
   ["Mary's Igloo"]="1889-5",
   ["Mashpee Wampanoag"]="1681-6",
   ["Matinecock"]="1326-8",
   ["Mattaponi"]="1354-0",
   ["Mattole"]="1060-3",
   ["Mauneluk Inupiat"]="1870-5",
   ["Mcgrath"]="1779-8",
   ["Mdewakanton Sioux"]="1620-4",
   ["Mekoryuk"]="1933-1",
   ["Melanesian"]="2100-6",
   ["Menominee"]="1356-5",
   ["Mentasta Lake"]="1781-4",
   ["Mesa Grande"]="1228-6",
   ["Mescalero Apache"]="1015-7",
   ["Metlakatla"]="1838-2",
   ["Mexican American Indian"]="1072-8",
   ["Miami"]="1358-1",
   ["Miccosukee"]="1363-1",
   ["Michigan Ottawa"]="1413-4",
   ["Micmac"]="1365-6",
   ["Micronesian"]="2085-9",
   ["Middle Eastern or North African"]="2118-8",
   ["Mille Lacs"]="1138-7",
   ["Miniconjou"]="1621-2",
   ["Minnesota Chippewa"]="1139-5",
   ["Minto"]="1782-2",
   ["Mission Indians"]="1368-0",
   ["Mississippi Choctaw"]="1158-5",
   ["Missouri Sac and Fox"]="1553-7",
   ["Miwok"]="1370-6",
   ["Moapa"]="1428-2",
   ["Modoc"]="1372-2",
   ["Mohave"]="1729-3",
   ["Mohawk"]="1287-2",
   ["Mohegan"]="1374-8",
   ["Molala"]="1396-1",
   ["Mono"]="1376-3",
   ["Montauk"]="1327-6",
   ["Moor"]="1237-7",
   ["Morongo"]="1049-6",
   ["Mountain Maidu"]="1345-8",
   ["Mountain Village"]="1934-9",
   ["Mowa Band of Choctaw"]="1159-3",
   ["Muckleshoot"]="1522-2",
   ["Munsee"]="1217-9",
   ["Naknek"]="1935-6",
   ["Nambe"]="1498-5",
   ["Namibian"]="2064-4",
   ["Nana Inupiat"]="1871-3",
   ["Nansemond"]="1238-5",
   ["Nanticoke"]="1378-9",
   ["Napakiak"]="1937-2",
   ["Napaskiak"]="1938-0",
   ["Napaumute"]="1936-4",
   ["Narragansett"]="1380-5",
   ["Natchez"]="1239-3",
   ["Native Hawaiian"]="2079-2",
   ["Native Hawaiian or Other Pacific Islander"]="2076-8",
   ["Nausu Waiwash"]="1240-1",
   ["Navajo"]="1382-1",
   ["Nebraska Ponca"]="1475-3",
   ["Nebraska Winnebago"]="1698-0",
   ["Nelson Lagoon"]="2016-4",
   ["Nenana"]="1783-0",
   ["Nepalese"]="2050-3",
   ["New Hebrides"]="2104-8",
   ["New Stuyahok"]="1940-6",
   ["Newhalen"]="1939-8",
   ["Newtok"]="1941-4",
   ["Nez Perce"]="1387-0",
   ["Nigerian"]="2065-1",
   ["Nightmute"]="1942-2",
   ["Nikolai"]="1784-8",
   ["Nikolski"]="2017-2",
   ["Ninilchik"]="1785-5",
   ["Nipmuc"]="1241-9",
   ["Nishinam"]="1346-6",
   ["Nisqually"]="1523-0",
   ["Noatak"]="1872-1",
   ["Nomalaki"]="1389-6",
   ["Nome"]="1873-9",
   ["Nondalton"]="1786-3",
   ["Nooksack"]="1524-8",
   ["Noorvik"]="1874-7",
   ["Northern Arapaho"]="1022-3",
   ["Northern Cherokee"]="1095-9",
   ["Northern Cheyenne"]="1103-1",
   ["Northern Paiute"]="1429-0",
   ["Northern Pomo"]="1469-6",
   ["Northway"]="1787-1",
   ["Northwest Tribes"]="1391-2",
   ["Nuiqsut"]="1875-4",
   ["Nulato"]="1788-9",
   ["Nunapitchukv"]="1943-0",
   ["Oglala Sioux"]="1622-0",
   ["Okinawan"]="2043-8",
   ["Oklahoma Apache"]="1016-5",
   ["Oklahoma Cado"]="1042-1",
   ["Oklahoma Choctaw"]="1160-1",
   ["Oklahoma Comanche"]="1176-7",
   ["Oklahoma Delaware"]="1218-7",
   ["Oklahoma Kickapoo"]="1306-0",
   ["Oklahoma Kiowa"]="1310-2",
   ["Oklahoma Miami"]="1361-5",
   ["Oklahoma Ottawa"]="1414-2",
   ["Oklahoma Pawnee"]="1446-4",
   ["Oklahoma Peoria"]="1451-4",
   ["Oklahoma Ponca"]="1476-1",
   ["Oklahoma Sac and Fox"]="1554-5",
   ["Oklahoma Seminole"]="1571-9",
   ["Old Harbor"]="1998-4",
   ["Omaha"]="1403-5",
   ["Oneida"]="1288-0",
   ["Onondaga"]="1289-8",
   ["Ontonagon"]="1140-3",
   ["Oregon Athabaskan"]="1405-0",
   ["Osage"]="1407-6",
   ["Oscarville"]="1944-8",
   ["Other Pacific Islander"]="2500-7",
   ["Other Race"]="2131-1",
   ["Otoe-Missouria"]="1409-2",
   ["Ottawa"]="1411-8",
   ["Ouzinkie"]="1999-2",
   ["Owens Valley"]="1430-8",
   ["Paiute"]="1416-7",
   ["Pakistani"]="2044-6",
   ["Pala"]="1333-4",
   ["Palauan"]="2091-7",
   ["Palestinian"]="2124-6",
   ["Pamunkey"]="1439-9",
   ["Panamint"]="1592-5",
   ["Papua New Guinean"]="2102-2",
   ["Pascua Yaqui"]="1713-7",
   ["Passamaquoddy"]="1441-5",
   ["Paugussett"]="1242-7",
   ["Pauloff Harbor"]="2018-0",
   ["Pauma"]="1334-2",
   ["Pawnee"]="1445-6",
   ["Payson Apache"]="1017-3",
   ["Pechanga"]="1335-9",
   ["Pedro Bay"]="1789-7",
   ["Pelican"]="1828-3",
   ["Penobscot"]="1448-0",
   ["Peoria"]="1450-6",
   ["Pequot"]="1453-0",
   ["Perryville"]="1980-2",
   ["Petersburg"]="1829-1",
   ["Picuris"]="1499-3",
   ["Pilot Point"]="1981-0",
   ["Pilot Station"]="1945-5",
   ["Pima"]="1456-3",
   ["Pine Ridge Sioux"]="1623-8",
   ["Pipestone Sioux"]="1624-6",
   ["Piro"]="1500-8",
   ["Piscataway"]="1460-5",
   ["Pit River"]="1462-1",
   ["Pitkas Point"]="1946-3",
   ["Platinum"]="1947-1",
   ["Pleasant Point Passamaquoddy"]="1443-1",
   ["Poarch Band"]="1201-3",
   ["Pocomoke Acohonock"]="1243-5",
   ["Pohnpeian"]="2094-1",
   ["Point Hope"]="1876-2",
   ["Point Lay"]="1877-0",
   ["Pojoaque"]="1501-6",
   ["Pokagon Potawatomi"]="1483-7",
   ["Polish"]="2115-4",
   ["Polynesian"]="2078-4",
   ["Pomo"]="1464-7",
   ["Ponca"]="1474-6",
   ["Poospatuck"]="1328-4",
   ["Port Gamble Klallam"]="1315-1",
   ["Port Graham"]="1988-5",
   ["Port Heiden"]="1982-8",
   ["Port Lions"]="2000-8",
   ["Port Madison"]="1525-5",
   ["Portage Creek"]="1948-9",
   ["Potawatomi"]="1478-7",
   ["Powhatan"]="1487-8",
   ["Prairie Band"]="1484-5",
   ["Prairie Island Sioux"]="1625-3",
   ["Principal Creek Indian Nation"]="1202-1",
   ["Prior Lake Sioux"]="1626-1",
   ["Pueblo"]="1489-4",
   ["Puget Sound Salish"]="1518-0",
   ["Puyallup"]="1526-3",
   ["Pyramid Lake"]="1431-6",
   ["Qagan Toyagungin"]="2019-8",
   ["Qawalangin"]="2020-6",
   ["Quapaw"]="1541-2",
   ["Quechan"]="1730-1",
   ["Quileute"]="1084-3",
   ["Quinault"]="1543-8",
   ["Quinhagak"]="1949-7",
   ["Ramah Navajo"]="1385-4",
   ["Rampart"]="1790-5",
   ["Rampough Mountain"]="1219-5",
   ["Rappahannock"]="1545-3",
   ["Red Cliff Chippewa"]="1141-1",
   ["Red Devil"]="1950-5",
   ["Red Lake Chippewa"]="1142-9",
   ["Red Wood"]="1061-1",
   ["Reno-Sparks"]="1547-9",
   ["Rocky Boy's Chippewa Cree"]="1151-0",
   ["Rosebud Sioux"]="1627-9",
   ["Round Valley"]="1549-5",
   ["Ruby"]="1791-3",
   ["Ruby Valley"]="1593-3",
   ["Sac and Fox"]="1551-1",
   ["Saginaw Chippewa"]="1143-7",
   ["Saipanese"]="2095-8",
   ["Salamatof"]="1792-1",
   ["Salinan"]="1556-0",
   ["Salish"]="1558-6",
   ["Salish and Kootenai"]="1560-2",
   ["Salt River Pima-Maricopa"]="1458-9",
   ["Samish"]="1527-1",
   ["Samoan"]="2080-0",
   ["San Carlos Apache"]="1018-1",
   ["San Felipe"]="1502-4",
   ["San Ildefonso"]="1503-2",
   ["San Juan"]="1506-5",
   ["San Juan De"]="1505-7",
   ["San Juan Pueblo"]="1504-0",
   ["San Juan Southern Paiute"]="1432-4",
   ["San Manual"]="1574-3",
   ["San Pasqual"]="1229-4",
   ["San Xavier"]="1656-8",
   ["Sand Hill"]="1220-3",
   ["Sand Point"]="2023-0",
   ["Sandia"]="1507-3",
   ["Sans Arc Sioux"]="1628-7",
   ["Santa Ana"]="1508-1",
   ["Santa Clara"]="1509-9",
   ["Santa Rosa"]="1062-9",
   ["Santa Rosa Cahuilla"]="1050-4",
   ["Santa Ynez"]="1163-5",
   ["Santa Ysabel"]="1230-2",
   ["Santee Sioux"]="1629-5",
   ["Santo Domingo"]="1510-7",
   ["Sauk-Suiattle"]="1528-9",
   ["Sault Ste. Marie Chippewa"]="1145-2",
   ["Savoonga"]="1893-7",
   ["Saxman"]="1830-9",
   ["Scammon Bay"]="1952-1",
   ["Schaghticoke"]="1562-8",
   ["Scott Valley"]="1564-4",
   ["Scottish"]="2116-2",
   ["Scotts Valley"]="1470-4",
   ["Selawik"]="1878-8",
   ["Seldovia"]="1793-9",
   ["Sells"]="1657-6",
   ["Seminole"]="1566-9",
   ["Seneca"]="1290-6",
   ["Seneca Nation"]="1291-4",
   ["Seneca-Cayuga"]="1292-2",
   ["Serrano"]="1573-5",
   ["Setauket"]="1329-2",
   ["Shageluk"]="1795-4",
   ["Shaktoolik"]="1879-6",
   ["Shasta"]="1576-8",
   ["Shawnee"]="1578-4",
   ["Sheldon's Point"]="1953-9",
   ["Shinnecock"]="1582-6",
   ["Shishmaref"]="1880-4",
   ["Shoalwater Bay"]="1584-2",
   ["Shoshone"]="1586-7",
   ["Shoshone Paiute"]="1602-2",
   ["Shungnak"]="1881-2",
   ["Siberian Eskimo"]="1891-1",
   ["Siberian Yupik"]="1894-5",
   ["Siletz"]="1607-1",
   ["Singaporean"]="2051-1",
   ["Sioux"]="1609-7",
   ["Sisseton Sioux"]="1631-1",
   ["Sisseton-Wahpeton"]="1630-3",
   ["Sitka"]="1831-7",
   ["Siuslaw"]="1643-6",
   ["Skokomish"]="1529-7",
   ["Skull Valley"]="1594-1",
   ["Skykomish"]="1530-5",
   ["Slana"]="1794-7",
   ["Sleetmute"]="1954-7",
   ["Snohomish"]="1531-3",
   ["Snoqualmie"]="1532-1",
   ["Soboba"]="1336-7",
   ["Sokoagon Chippewa"]="1146-0",
   ["Solomon"]="1882-0",
   ["Solomon Islander"]="2103-0",
   ["South American Indian"]="1073-6",
   ["South Fork Shoshone"]="1595-8",
   ["South Naknek"]="2024-8",
   ["Southeast Alaska"]="1811-9",
   ["Southeastern Indians"]="1244-3",
   ["Southern Arapaho"]="1023-1",
   ["Southern Cheyenne"]="1104-9",
   ["Southern Paiute"]="1433-2",
   ["Spanish American Indian"]="1074-4",
   ["Spirit Lake Sioux"]="1632-9",
   ["Spokane"]="1645-1",
   ["Squaxin Island"]="1533-9",
   ["Sri Lankan"]="2045-3",
   ["St. Croix Chippewa"]="1144-5",
   ["St. George"]="2021-4",
   ["St. Mary's"]="1963-8",
   ["St. Michael"]="1951-3",
   ["St. Paul"]="2022-2",
   ["Standing Rock Sioux"]="1633-7",
   ["Star Clan of Muscogee Creeks"]="1203-9",
   ["Stebbins"]="1955-4",
   ["Steilacoom"]="1534-7",
   ["Stevens"]="1796-2",
   ["Stewart"]="1647-7",
   ["Stillaguamish"]="1535-4",
   ["Stockbridge"]="1649-3",
   ["Stony River"]="1797-0",
   ["Stonyford"]="1471-2",
   ["Sugpiaq"]="2002-4",
   ["Sulphur Bank"]="1472-0",
   ["Summit Lake"]="1434-0",
   ["Suqpigaq"]="2004-0",
   ["Suquamish"]="1536-2",
   ["Susanville"]="1651-9",
   ["Susquehanock"]="1245-0",
   ["Swinomish"]="1537-0",
   ["Sycuan"]="1231-0",
   ["Syrian"]="2125-3",
   ["Table Bluff"]="1705-3",
   ["Tachi"]="1719-4",
   ["Tahitian"]="2081-8",
   ["Taiwanese"]="2035-4",
   ["Takelma"]="1063-7",
   ["Takotna"]="1798-8",
   ["Talakamish"]="1397-9",
   ["Tanacross"]="1799-6",
   ["Tanaina"]="1800-2",
   ["Tanana"]="1801-0",
   ["Tanana Chiefs"]="1802-8",
   ["Taos"]="1511-5",
   ["Tatitlek"]="1969-5",
   ["Tazlina"]="1803-6",
   ["Telida"]="1804-4",
   ["Teller"]="1883-8",
   ["Temecula"]="1338-3",
   ["Te-Moak Western Shoshone"]="1596-6",
   ["Tenakee Springs"]="1832-5",
   ["Tenino"]="1398-7",
   ["Tesuque"]="1512-3",
   ["Tetlin"]="1805-1",
   ["Teton Sioux"]="1634-5",
   ["Tewa"]="1513-1",
   ["Texas Kickapoo"]="1307-8",
   ["Thai"]="2046-1",
   ["Thlopthlocco"]="1204-7",
   ["Tigua"]="1514-9",
   ["Tillamook"]="1399-5",
   ["Timbi-Sha Shoshone"]="1597-4",
   ["Tlingit"]="1833-3",
   ["Tlingit-Haida"]="1813-5",
   ["Tobagoan"]="2073-5",
   ["Togiak"]="1956-2",
   ["Tohono O'Odham"]="1653-5",
   ["Tok"]="1806-9",
   ["Tokelauan"]="2083-4",
   ["Toksook"]="1957-0",
   ["Tolowa"]="1659-2",
   ["Tonawanda Seneca"]="1293-0",
   ["Tongan"]="2082-6",
   ["Tonkawa"]="1661-8",
   ["Torres-Martinez"]="1051-2",
   ["Trinidadian"]="2074-3",
   ["Trinity"]="1272-4",
   ["Tsimshian"]="1837-4",
   ["Tuckabachee"]="1205-4",
   ["Tulalip"]="1538-8",
   ["Tule River"]="1720-2",
   ["Tulukskak"]="1958-8",
   ["Tunica Biloxi"]="1246-8",
   ["Tuntutuliak"]="1959-6",
   ["Tununak"]="1960-4",
   ["Turtle Mountain"]="1147-8",
   ["Tuscarora"]="1294-8",
   ["Tuscola"]="1096-7",
   ["Twenty-Nine Palms"]="1337-5",
   ["Twin Hills"]="1961-2",
   ["Two Kettle Sioux"]="1635-2",
   ["Tygh"]="1663-4",
   ["Tyonek"]="1807-7",
   ["Ugashik"]="1970-3",
   ["Uintah Ute"]="1672-5",
   ["Umatilla"]="1665-9",
   ["Umkumiate"]="1964-6",
   ["Umpqua"]="1667-5",
   ["Unalakleet"]="1884-6",
   ["Unalaska"]="2025-5",
   ["Unangan Aleut"]="2006-5",
   ["Unga"]="2026-3",
   ["United Keetowah Band of Cherokee"]="1097-5",
   ["Upper Chinook"]="1118-9",
   ["Upper Sioux"]="1636-0",
   ["Upper Skagit"]="1539-6",
   ["Ute"]="1670-9",
   ["Ute Mountain Ute"]="1673-3",
   ["Utu Utu Gwaitu Paiute"]="1435-7",
   ["Venetie"]="1808-5",
   ["Vietnamese"]="2047-9",
   ["Waccamaw-Siousan"]="1247-6",
   ["Wahpekute Sioux"]="1637-8",
   ["Wahpeton Sioux"]="1638-6",
   ["Wailaki"]="1675-8",
   ["Wainwright"]="1885-3",
   ["Wakiakum Chinook"]="1119-7",
   ["Wales"]="1886-1",
   ["Walker River"]="1436-5",
   ["Walla-Walla"]="1677-4",
   ["Wampanoag"]="1679-0",
   ["Wappo"]="1064-5",
   ["Warm Springs"]="1683-2",
   ["Wascopum"]="1685-7",
   ["Washakie"]="1598-2",
   ["Washoe"]="1687-3",
   ["Wazhaza Sioux"]="1639-4",
   ["Wenatchee"]="1400-1",
   ["West Indian"]="2075-0",
   ["Western Cherokee"]="1098-3",
   ["Western Chickahominy"]="1110-6",
   ["Whilkut"]="1273-2",
   ["White"]="2106-3",
   ["White Earth"]="1148-6",
   ["White Mountain"]="1887-9",
   ["White Mountain Apache"]="1019-9",
   ["White Mountain Inupiat"]="1888-7",
   ["Wichita"]="1692-3",
   ["Wicomico"]="1248-4",
   ["Willapa Chinook"]="1120-5",
   ["Wind River"]="1694-9",
   ["Wind River Arapaho"]="1024-9",
   ["Wind River Shoshone"]="1599-0",
   ["Winnebago"]="1696-4",
   ["Winnemucca"]="1700-4",
   ["Wintun"]="1702-0",
   ["Wisconsin Potawatomi"]="1485-2",
   ["Wiseman"]="1809-3",
   ["Wishram"]="1121-3",
   ["Wiyot"]="1704-6",
   ["Wrangell"]="1834-1",
   ["Wyandotte"]="1295-5",
   ["Yahooskin"]="1401-9",
   ["Yakama"]="1707-9",
   ["Yakama Cowlitz"]="1709-5",
   ["Yakutat"]="1835-8",
   ["Yana"]="1065-2",
   ["Yankton Sioux"]="1640-2",
   ["Yanktonai Sioux"]="1641-0",
   ["Yapese"]="2098-2",
   ["Yaqui"]="1711-1",
   ["Yavapai"]="1731-9",
   ["Yavapai Apache"]="1715-2",
   ["Yerington Paiute"]="1437-3",
   ["Yokuts"]="1717-8",
   ["Yomba"]="1600-6",
   ["Yuchi"]="1722-8",
   ["Yuki"]="1066-0",
   ["Yuman"]="1724-4",
   ["Yupik Eskimo"]="1896-0",
   ["Yurok"]="1732-7",
   ["Zairean"]="2066-9",
   ["Zia"]="1515-6",
   ["Zuni"]="1516-4",
}

cda.codeset.race.reverse = Reverse(cda.codeset.race)

-- cda.codeset.cat : ["HL7 Race and Ethnicity"] = "2.16.840.1.113883.6.238"
cda.codeset.ethnicGroup = {
   ["Hispanic or Latino"] = "2135-2",
   ["Not Hispanic or Latino"] = "2186-5"
}

cda.codeset.ethnicGroup.reverse = Reverse(cda.codeset.ethnicGroup)